@@ -2,7 +2,7 @@
 #
 #   Math::Polynom - Operations on polynoms
 #
-#   $Id: Polynom.pm,v 1.4 2007/04/12 13:28:57 erwan_lemonnier Exp $
+#   $Id: Polynom.pm,v 1.5 2007/04/17 19:47:27 erwan_lemonnier Exp $
 #
 #   061025 erwan Started implementation
 #   061206 erwan Added the secant method
@@ -10,6 +10,7 @@
 #   070112 erwan Fixed bug in identification of nan scalars
 #   070220 erwan Updated POD to warn for convergence toward non roots
 #   070404 erwan Added $DEBUG
+#   070417 erwan Modified disclaimer
 #
 
 package Math::Polynom;
@@ -30,7 +31,7 @@ use constant ERROR_DIVIDE_BY_ZERO => 4;
 use constant ERROR_WRONG_SIGNS    => 5;
 use constant ERROR_NOT_A_ROOT     => 6;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 our $DEBUG = 0;
 
 #----------------------------------------------------------------
@@ -936,24 +937,27 @@ See Math::Calculus::NewtonRaphson, Math::Polynomial, Math::Function::Roots.
 
 =head1 VERSION
 
-$Id: Polynom.pm,v 1.4 2007/04/12 13:28:57 erwan_lemonnier Exp $
+$Id: Polynom.pm,v 1.5 2007/04/17 19:47:27 erwan_lemonnier Exp $
 
 =head1 THANKS
 
 Thanks to Spencer Ogden who wrote the implementation of the Secant algorithm in his module Math::Function::Roots.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Erwan Lemonnier C<< <erwan@cpan.org> >>
+Erwan Lemonnier C<< <erwan@cpan.org> >>, 
+as part of the Pluto developer group at the Swedish Premium Pension Authority.
 
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE
 
-This code is distributed under the same terms as Perl itself.
+This code was developed at the Swedish Premium Pension Authority as part of
+the Authority's software development activities. This code is distributed
+under the same terms as Perl itself. We encourage you to help us improving
+this code by sending feedback and bug reports to the author(s).
 
-=head1 DISCLAIMER OF WARRANTY
-
-This is free code and comes with no warranty. The author declines any personal
-responsibility regarding the use of this code or the consequences of its use.
+This code comes with no warranty. The Swedish Premium Pension Authority and the author(s)
+decline any responsibility regarding the possible use of this code or any consequence
+of its use.
 
 =cut
 
